Learn R Programming

AllMetrics (version 0.2.1)

all_metrics: Calculating Multiple Performance Metrics of a Prediction Model

Description

This provides a function to calculate multiple performance metrics for actual and predicted values.

Usage

all_metrics(actual, predicted)

Value

  • AllMetrics - A data frame containing two columns with first column as the name of the eight metrics and second column as the corresponding values

Arguments

actual

This is the actual time series values

predicted

This is the predicted values of a time series using a model

References

  • Garai, S., & Paul, R. K. (2023). Development of MCS based-ensemble models using CEEMDAN decomposition and machine intelligence. Intelligent Systems with Applications, 18, 200202.

  • Garai, S., Paul, R. K., Kumar, M., & Choudhury, A. (2023). Intra-annual National Statistical Accounts Based on Machine Learning Algorithm. Journal of Data Science and Intelligent Systems. https://doi.org/10.47852/bonviewJDSIS3202870

  • Garai, S., Paul, R.K., Yeasin, M., Paul, A.K. (2024). CEEMDAN-Based Hybrid Machine Learning Models for Time Series Forecasting Using MARS Algorithm and PSO-Optimization. Neural Processing Letters, 56, 92. https://doi.org/10.1007/s11063-024-11552-w

Examples

Run this code
actual <- c(1.5, 2.3, 25, 52, 14)
predicted <- c(1.2, 10, 3.5, 4.3, 5.6)
# Inside the function 1st specify actual then predicted
print(all_metrics(actual, predicted))

Run the code above in your browser using DataLab